@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -36,7 +35,7 @@
  * <para><emphasis>Beware that this convention is not always well followed.</emphasis></para>
  */
 
-#include "./export.h"
+#include "export.h"
 
 LASSO_EXPORT const char* lasso_strerror(int error_code);
 
@@ -114,6 +113,12 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  * An XML tree does not respect at least an XML schema of its namespaces.
  */
 #define LASSO_XML_ERROR_SCHEMA_INVALID_FRAGMENT         17
+/**
+ * LASSO_XML_ERROR_ATTR_VALUE_INVALID:
+ *
+ * Attribute value is invalid.
+ */
+#define LASSO_XML_ERROR_ATTR_VALUE_INVALID -18
 
 /* XMLDSig */
 /**
@@ -263,6 +268,15 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  * Parsed XML is invalid.
  */
 #define LASSO_SERVER_ERROR_INVALID_XML -205
+/**
+ * LASSO_SERVER_ERROR_NO_PROVIDER_LOADED
+ *
+ * When loading a metadata file it indicates that no provider could be loaded.
+ * It could be because the file is not well formed, or because there is no provider for the
+ * role sought.
+ *
+ */
+#define LASSO_SERVER_ERROR_NO_PROVIDER_LOADED 206
 
 /* Single Logout */
 /**
@@ -289,6 +303,12 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  * Unknown principal on logout
  */
 #define LASSO_LOGOUT_ERROR_UNKNOWN_PRINCIPAL 304
+/**
+ * LASSO_LOGOUT_ERROR_PARTIAL_LOGOUT:
+ *
+ * Logout could not be propagated to every service provider in the current session.
+ */
+#define LASSO_LOGOUT_ERROR_PARTIAL_LOGOUT 305
 
 /* Profile */
 /**
@@ -588,7 +608,26 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  * The issuer of an assertion is not considered as an IdP
  */
 #define LASSO_PROFILE_ERROR_ISSUER_IS_NOT_AN_IDP 449
-
+/**
+ * LASSO_PROFILE_ERROR_REQUEST_DENIED:
+ *
+ * Generic error when an IdP or an SP return the RequestDenied status code in its response.
+ *
+ */
+#define LASSO_PROFILE_ERROR_REQUEST_DENIED 450
+/**
+ * LASSO_PROFILE_ERROR_ENDPOINT_INDEX_NOT_FOUND
+ *
+ * A received artifact contains an andpoint index which does not exist in the metadata of the
+ * corresponding provider.
+ */
+#define LASSO_PROFILE_ERROR_ENDPOINT_INDEX_NOT_FOUND 451
+/**
+ * LASSO_PROFILE_ERROR_INVALID_IDP_LIST
+ *
+ * The IDP list is invalid
+ */
+#define LASSO_PROFILE_ERROR_INVALID_IDP_LIST 452
 
 /* functions/methods parameters checking */
 /**
@@ -1055,3 +1094,66 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  * The current assertion query does not contain an attribute query.
  */
 #define LASSO_ASSERTION_QUERY_ERROR_NOT_AN_ATTRIBUTE_QUERY 1902
+
+/**
+ * LASSO_XMLENC_ERROR_INVALID_ENCRYPTED_DATA
+ *
+ * The EncryptedData node is invalid, look at the logs.
+ */
+#define LASSO_XMLENC_ERROR_INVALID_ENCRYPTED_DATA -2001
+
+/**
+ * LASSO_PAOS_ERROR_MISSING_REQUEST
+ *
+ * Missing PAOS Request
+ */
+#define LASSO_PAOS_ERROR_MISSING_REQUEST -2101
+/**
+ * LASSO_PAOS_ERROR_MISSING_RESPONSE
+ *
+ * Missing PAOS Response
+ */
+#define LASSO_PAOS_ERROR_MISSING_RESPONSE -2102
+/**
+ * LASSO_PAOS_ERROR_MISSING_RESPONSE_CONSUMER_URL
+ *
+ * Missing paos:Request responseConsumerURL
+ */
+#define LASSO_PAOS_ERROR_MISSING_RESPONSE_CONSUMER_URL -2103
+
+/**
+ * LASSO_ECP_ERROR_MISSING_REQUEST
+ *
+ * Missing ECP Request
+ */
+#define LASSO_ECP_ERROR_MISSING_REQUEST -2201
+/**
+ * LASSO_ECP_ERROR_MISSING_RESPONSE
+ *
+ * Missing ECP Response
+ */
+#define LASSO_ECP_ERROR_MISSING_RESPONSE -2202
+/**
+ * LASSO_ECP_ERROR_MISSING_RELAYSTATE
+ *
+ * Missing ECP RelayState
+ */
+#define LASSO_ECP_ERROR_MISSING_RELAYSTATE -2203
+/**
+ * LASSO_ECP_ERROR_MISSING_AUTHN_REQUEST
+ *
+ * Missing samlp:AuthnRequest in ECP request
+ */
+#define LASSO_ECP_ERROR_MISSING_AUTHN_REQUEST -2204
+/**
+ * LASSO_ECP_ERROR_MISSING_SAML_RESPONSE
+ *
+ * Missing samlp:Response in IdP ECP response
+ */
+#define LASSO_ECP_ERROR_MISSING_SAML_RESPONSE -2205
+/**
+ * LASSO_ECP_ERROR_ASSERTION_CONSUMER_URL_MISMATCH
+ *
+ * The ecp:Request responseConsumerURL and ecp:Response AssertionConsumerURL do not match
+ */
+#define LASSO_ECP_ERROR_ASSERTION_CONSUMER_URL_MISMATCH -2206
