@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -61,8 +60,8 @@
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
-#include "./discovery.h"
-#include "./data_service.h"
+#include "discovery.h"
+#include "data_service.h"
 #include "../xml/idwsf_strings.h"
 #include "../xml/dst_query.h"
 #include "../xml/dst_query_response.h"
@@ -76,7 +75,7 @@
 #include <xmlsec/xmldsig.h>
 #include <xmlsec/templates.h>
 #include <xmlsec/crypto.h>
-#include "./wsf_profile_private.h"
+#include "wsf_profile_private.h"
 
 extern GHashTable *dst_services_by_prefix; /* cf xml/xml.c */
 
@@ -1156,7 +1155,7 @@ instance_init(LassoDataService *service)
 }
 
 static void
-class_init(LassoDataServiceClass *klass)
+class_init(LassoDataServiceClass *klass, void *unused G_GNUC_UNUSED)
 {
 	parent_class = g_type_class_peek_parent(klass);
 
