@@ -29,7 +29,6 @@
 #include <xmlsec/xmldsig.h>
 #include <xmlsec/templates.h>
 #include <xmlsec/crypto.h>
-#include <xmlsec/soap.h>
 
 #include "../utils.h"
 
@@ -1090,7 +1089,7 @@ instance_init(LassoWsfProfile *profile)
 }
 
 static void
-class_init(LassoWsfProfileClass *klass)
+class_init(LassoWsfProfileClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -1369,7 +1368,7 @@ lasso_wsf_profile_add_saml_signature(LassoWsfProfile *wsf_profile, xmlDoc *doc)
 
 	/* Lookup all referenced node and their Ids */
 	envelope = xmlDocGetRootElement(doc);
-	header = xmlSecSoap11GetHeader(envelope);
+	header = lasso_xml_soap11_get_header(envelope);
 
 	provider = xmlSecFindNode(header, (xmlChar*) "Provider",
 		(xmlChar*) LASSO_SOAP_BINDING_HREF);
@@ -1377,7 +1376,7 @@ lasso_wsf_profile_add_saml_signature(LassoWsfProfile *wsf_profile, xmlDoc *doc)
 		(xmlChar*) LASSO_SOAP_BINDING_HREF);
 	interaction = xmlSecFindNode(header, (xmlChar*) "UserInteraction",
 		(xmlChar*) LASSO_IS_HREF);
-	body = xmlSecSoap11GetBody(envelope);
+	body = lasso_xml_soap11_get_body(envelope);
 	xmlSecAddIDs(doc, envelope, ids);
 	goto_cleanup_if_fail_with_rc(header != NULL, LASSO_XML_ERROR_NODE_NOT_FOUND);
 	goto_cleanup_if_fail_with_rc(provider != NULL, LASSO_XML_ERROR_NODE_NOT_FOUND);
