@@ -86,7 +86,7 @@ static struct XmlSnippet schema_snippets[] = {
 /*****************************************************************************/
 
 static void
-class_init(LassoDiscoDescriptionClass *klass)
+class_init(LassoDiscoDescriptionClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
