@@ -69,7 +69,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2ImsMappingInputClass *klass)
+class_init(LassoIdWsf2ImsMappingInputClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
