@@ -61,7 +61,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2PsItemDataClass *klass)
+class_init(LassoIdWsf2PsItemDataClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
