@@ -63,7 +63,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2Sb2EndpointUpdateClass *klass)
+class_init(LassoIdWsf2Sb2EndpointUpdateClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
