@@ -54,7 +54,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2SubsRefAppDataClass *klass)
+class_init(LassoIdWsf2SubsRefAppDataClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
