@@ -80,7 +80,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoIsInteractionRequestClass *klass)
+class_init(LassoIsInteractionRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
