@@ -63,7 +63,7 @@ instance_init(LassoLibScoping *node)
 }
 
 static void
-class_init(LassoLibScopingClass *klass)
+class_init(LassoLibScopingClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
