@@ -87,7 +87,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoSaml2SubjectConfirmationDataClass *klass)
+class_init(LassoSaml2SubjectConfirmationDataClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
